# ls

```
usage: ls [-h] [path [path ...]]

List members of a group

positional arguments:
  path        Paths to list the members of

optional arguments:
  -h, --help  show this help message and exit
```
